import Box from "@mui/material/Box";
import Typography from "@mui/material/Typography";
import useMediaQuery from "@mui/material/useMediaQuery";
import { useTheme } from "@mui/material/styles";

const dob = new Date(2002, 4, 3);
const age = Math.abs(
  new Date(Date.now() - dob.getTime()).getUTCFullYear() - 1970,
);

function AboutContact(props) {
  const { title, info } = props;
  return (
    <Typography sx={{ fontWeight: 600 }}>
      {`${title}:`}
      <span
        style={{
          fontFamily: "inherit",
          paddingLeft: ".5rem",
          fontSize: "14px",
        }}
      >
        {info}
      </span>
    </Typography>
  );
}

export default function About() {
  const theme = useTheme();
  const fullSizePhoto = useMediaQuery(theme.breakpoints.down("md"));
  return (
    <Box>
      <Box
        sx={{
          m: "0rem 0 2rem 0",
          padding: "0 2rem",
          textAlign: "left",
        }}
        style={{ scrollMarginTop: "6rem" }}
        id="about"
      >
        <Box sx={{ display: "flex", flexWrap: "wrap" }}>
          {!fullSizePhoto && (
            <img
              src="/resume/About.jpeg"
              style={{
                width: "100%",
                maxWidth: "400px",
                height: "100%",
                padding: "0 1rem",
                borderRadius: "10%",
              }}
            />
          )}
          {fullSizePhoto && (
            <img
              src="/resume/About.jpeg"
              style={{
                width: "90%",
                height: "90%",
                margin: "0 auto",
                borderRadius: "10%",
              }}
            />
          )}
          <Box
            sx={{
              minWidth: "180px",
              maxWidth: fullSizePhoto ? "100%" : "700px",
              width: "100%",
              display: fullSizePhoto ? "flex" : "block",
              flex: "1 1 180px",
              flexWrap: "wrap",
              margin: fullSizePhoto ? "0" : "0 0 0 1rem",
              pt: fullSizePhoto ? "2rem" : "0",
            }}
          >
            <Typography variant="h6" component="div" sx={{ fontWeight: 600 }}>
              About
            </Typography>
            <Typography variant="body1">
              Hello! I'm Elijah Parker, a fullstack software engineer from Utah.
              I have a passion for developing software that achieves "the
              impossible". I have experience using a wide variety of
              technologies including React, Python, Java, and Kubernetes. I'm
              currently seeking an entry-level part time position or internship
              with flexible hours to accommodate pursuit of a bachelorette
              degree.
            </Typography>
            <Box
              className="about-contacts"
              sx={{
                pt: "2rem",
                display: "flex",
                flexWrap: "wrap",
                width: "100%",
                overflow: "hidden",
              }}
            >
              <Box className="about-contacts-left" sx={{ minWidth: "50%" }}>
                <AboutContact
                  title="Email"
                  info={
                    <a
                      href="mailto:elijahglennparker@outlook.com"
                      style={{ textDecoration: "none", fontSize: "14px" }}
                    >
                      elijahglennparker@outlook.com
                    </a>
                  }
                />
                <AboutContact title="From" info="Utah, USA" />
              </Box>
              <Box className="about-contacts-right" sx={{ minWidth: "50%" }}>
                <AboutContact title="Age" info={age} />
                <AboutContact title="Freelance" info="Available" />
              </Box>
            </Box>
            <Typography variant="body1" sx={{ mt: "2rem" }}>
              Additionally, I have worked with a wide range of tools and
              frameworks including Git, PostgreSQL, MongoDB, Docker, Kubernetes,
              Garden, JavaFX, MaterialUI, Spring Boot, Express, Gitlab, Gitea
              CI/CD.
            </Typography>
          </Box>
        </Box>
      </Box>
    </Box>
  );
}
