import { useState } from "react";
import { Link } from "react-router-dom";
import Box from "@mui/material/Box";
import Button from "@mui/material/Button";
import Typography from "@mui/material/Typography";
import TextField from "@mui/material/TextField";
import MailIcon from "@mui/icons-material/Mail";
import LocationOnIcon from "@mui/icons-material/LocationOn";
import PhoneIphoneIcon from "@mui/icons-material/PhoneIphone";
import ContactStrip from "./ContactStrip.jsx";
import useMediaQuery from "@mui/material/useMediaQuery";
import { useTheme, styled } from "@mui/material/styles";
import "@css/contact.css";

const ContactMessageButton = styled(Button)({
  backgroundColor: "white",
  color: "#F3AC20",
  borderColor: "#F3AC20",

  "&:hover": {
    backgroundColor: "#F3AC20",
    color: "white",
    borderColor: "#F3AC20",
  },
});

export default function Contact() {
  const theme = useTheme();
  const minifyContact = useMediaQuery(theme.breakpoints.down("md"));
  const [contactName, setContactName] = useState();
  const [contactEmail, setContactEmail] = useState();
  const [contactSubject, setContactSubject] = useState();
  const [contactBody, setContactBody] = useState();

  const fillForm = (form) => (e) => form(e.target.value);

  return (
    <Box style={{ padding: 10, scrollMarginTop: "4rem" }} id="contact">
      <Box
        style={{
          display: "flex",
          flex: 1,
          margin: "auto",
          flexWrap: "wrap",
        }}
      >
        <Box style={{ flex: 1 }}>
          <div style={{ display: "flex" }}>
            <Typography variant="h2" sx={{ margin: "2rem auto", fontSize: 30 }}>
              Contact
            </Typography>
          </div>
          <Box
            className="static-contacts"
            style={{
              display: "flex",
              justifyContent: "center",
              flexWrap: "wrap",
            }}
          >
            <ContactStrip
              icon={LocationOnIcon}
              title="Location"
              info="Springville, Utah"
            />
            <ContactStrip
              icon={MailIcon}
              title="Email"
              info="elijahglennparker@outlook.com"
            />
            {/*<ContactStrip
              icon={PhoneIphoneIcon}
              title="Text/Call"
              info="+1 (234) 456 7890"
            />*/}
          </Box>
          <Box
            className="messaging"
            sx={{
              display: "flex",
              flexWrap: "wrap",
              gap: "1.5rem",
              maxWidth: "42em",
              width: "100%",
              m: "0 auto",
            }}
          >
            <Box
              className="messaging-head"
              sx={{
                display: "flex",
                justifyContent: "center",
                gap: "1.5rem",
                width: "100%",
                flexWrap: "wrap",
              }}
            >
              <TextField
                label="Name"
                size="small"
                sx={{
                  maxWidth: minifyContact ? "100%" : "20em",
                  width: "100%",
                }}
                onChange={fillForm(setContactName)}
                required
                type="name"
              />
              <TextField
                label="Email"
                size="small"
                sx={{
                  maxWidth: minifyContact ? "100%" : "20em",
                  width: "100%",
                }}
                onChange={fillForm(setContactEmail)}
                required
                type="email"
              />
            </Box>
            <TextField
              label="Subject"
              size="small"
              sx={{ width: "100%" }}
              onChange={fillForm(setContactSubject)}
              required
            />
            <TextField
              label="Message"
              size="small"
              multiline
              sx={{ width: "100%" }}
              maxRows={5}
              minRows={3}
              onChange={fillForm(setContactBody)}
              required
            />
            <ContactMessageButton
              variant="outlined"
              sx={{ m: "0 auto", width: "100%", maxWidth: "16em" }}
              component={Link}
              to={`mailto:elijahglennparker@outlook.com?subject=${contactSubject} | ${contactName} | ${contactEmail}&body=${contactBody}`}
              disabled={
                !(contactSubject && contactBody && contactName && contactEmail)
              }
            >
              Send Message
            </ContactMessageButton>
          </Box>
        </Box>
      </Box>
    </Box>
  );
}
