import React, { Suspense, useState } from "react";
import { FaReact, FaPython, FaJava, FaHtml5 } from "react-icons/fa";
import { SiJavascript } from "react-icons/si";
import Typography from "@mui/material/Typography";
import Box from "@mui/material/Box";
import Card from "@mui/material/Card";
import CardContent from "@mui/material/CardContent";
import SkillPaper from "./SkillPaper.jsx";
import PhotoHover from "./PhotoHover.jsx";
import Skeleton from "@mui/material/Skeleton";

import "react-responsive-carousel/lib/styles/carousel.min.css";
import { Carousel } from "react-responsive-carousel";

export default function Skills() {
  const carouselInterval = 7000;
  const [image, setImage] = useState();
  const [open, setOpen] = useState(false);

  function openPhoto(image) {
    setImage(image);
    setOpen(true);
  }

  const bottegaCertClick = () => openPhoto("/portfolio/bottega-cert.png");
  const testoutCertClick = () => openPhoto("/portfolio/linux-cert.png");

  const skills = [
    <SkillPaper
      src="/portfolio/iq/python.png"
      fgColor="white"
      bgColor="#3f7ed4"
      heading="Python"
      Icon={FaPython}
    />,
    <SkillPaper
      src="/portfolio/iq/react.png"
      fgColor="black"
      bgColor="#61dafb"
      heading="React"
      Icon={FaReact}
    />,
    <SkillPaper
      src="/portfolio/iq/java.png"
      fgColor="white"
      bgColor="#ea8c10 "
      heading="Java"
      Icon={FaJava}
    />,
    <SkillPaper
      src="/portfolio/iq/javascript.png"
      fgColor="black"
      bgColor="#edd43a"
      heading="Javascript"
      Icon={SiJavascript}
    />,
    <SkillPaper
      src="/portfolio/iq/html.png"
      fgColor="white"
      bgColor="#e9562f"
      heading="HTML 5"
      Icon={FaHtml5}
    />,
  ];

  const openSkill = (skillIndex) => openPhoto(skills[skillIndex].props.src);

  return (
    <Box style={{ padding: 10, scrollMarginTop: "4rem" }} id="achievements">
      <PhotoHover
        image={image}
        open={open}
        setOpen={setOpen}
        alt={"Certificate"}
      />
      <Box
        style={{
          display: "flex",
          flex: 1,
          margin: "auto",
          flexWrap: "wrap",
        }}
      >
        <Box style={{ flex: 1 }}>
          <div style={{ display: "flex" }}>
            <Typography variant="h2" sx={{ margin: "2rem auto", fontSize: 30 }}>
              Certifications
            </Typography>
          </div>
          <Box
            style={{
              flex: 1,
              textAlign: "left",
              display: "flex",
              flexGrow: 1,
              flexWrap: "wrap",
              justifyContent: "center",
            }}
          >
            <Card
              sx={{
                maxWidth: 374,
                margin: "10px auto",
                boxShadow:
                  "0 10px 16px 0 rgba(0,0,0,0.2),0 6px 20px 0 rgba(0,0,0,0.19)",
              }}
            >
              <img
                src="/portfolio/bottega-cert.png"
                style={{ width: "100%" }}
                title="Fullstack Development Certificate"
                onClick={bottegaCertClick}
              />
              <CardContent sx={{ color: "white", backgroundColor: "#1d9246" }}>
                <Typography gutterBottom variant="h5" component="div">
                  Fullstack Certification
                </Typography>
                <Typography variant="body2">
                  Certificate of profeciency in Python3, React, CSS, and
                  Javascript
                </Typography>
              </CardContent>
            </Card>
            <Card
              sx={{
                maxWidth: 374,
                margin: "10px auto",
                boxShadow:
                  "0 10px 16px 0 rgba(0,0,0,0.2),0 6px 20px 0 rgba(0,0,0,0.19)",
                backgroundColor: "#c3802b",
              }}
            >
              <img
                src="/portfolio/linux-cert.png"
                style={{ width: "100%" }}
                onClick={testoutCertClick}
                title="Linux Client Administration Certificate"
              />
              <CardContent
                sx={{
                  color: "white",
                }}
              >
                <Typography gutterBottom variant="h5" component="div">
                  Linux Administration Certificate
                </Typography>
                <Typography variant="body2">
                  Certificate of profeciency in Linux client administration
                </Typography>
              </CardContent>
            </Card>
          </Box>
        </Box>
      </Box>
      <Box
        style={{
          display: "flex",
          flex: 1,
          margin: "auto",
          flexWrap: "wrap",
        }}
      >
        <Box sx={{ flex: 1, textAlign: "left", width: "100%", pt: "2.5rem" }}>
          <Box
            sx={{
              width: "100%",
              maxWidth: 374,
              display: "block",
              margin: "auto",
              boxShadow:
                "0 10px 16px 0 rgba(0,0,0,0.2),0 6px 20px 0 rgba(0,0,0,0.19)",
            }}
          >
            <Suspense
              fallback={
                <Skeleton variant="rectangular" width="374px" height="100%" />
              }
            >
              <Carousel
                showArrows={true}
                showStatus={false}
                showIndicators={false}
                useKeyboardArrows={false}
                showThumbs={false}
                onClickItem={openSkill}
                infiniteLoop={true}
                interval={carouselInterval}
                autoPlay={true}
              >
                {skills.map((skill, i) => (
                  <React.Fragment key={skill}>{skill}</React.Fragment>
                ))}
              </Carousel>
            </Suspense>
          </Box>
        </Box>
      </Box>
    </Box>
  );
}
